pub struct RolloutReader;Implementations
Sourceimpl RolloutReader
impl RolloutReader
Sourcepub fn read_session<P: AsRef<Path>>(path: P) -> Result<Session>
pub fn read_session<P: AsRef<Path>>(path: P) -> Result<Session>
Read every line of a rollout file into a Session.
The session id is taken from the first line’s session_meta
payload if present; otherwise from the filename stem.