pub enum EventMsg {
TaskStarted(Value),
TaskComplete(Value),
UserMessage(Value),
AgentMessage(Value),
TokenCount(Box<TokenCountEvent>),
ExecCommandEnd(Box<ExecCommandEnd>),
PatchApplyEnd(Box<PatchApplyEnd>),
Other {
kind: String,
payload: Value,
},
}Expand description
Non-model events: task lifecycle, exec results, patch application,
token accounting, and a long tail of less common variants. The
crate strongly-types the common ones and captures the rest as raw
Value.
Variants
TaskStarted(Value)
TaskComplete(Value)
UserMessage(Value)
AgentMessage(Value)
TokenCount(Box<TokenCountEvent>)
ExecCommandEnd(Box<ExecCommandEnd>)
PatchApplyEnd(Box<PatchApplyEnd>)
Other
Implementations